<?php

namespace App\Forms;


use App\Entity\Pracoviste;
use App\Entity\Pracovnik;
use App\Entity\PracovniPozice;
use Doctrine\ORM\EntityManager;

class PracovisteForm
{

	/** @var  FormFactory  */
	protected $formFactory;

	/** @var  EntityManager */
	protected $em;

	public function __construct(FormFactory $formFactory, EntityManager $em)
	{
		$this->formFactory = $formFactory;
		$this->em = $em;
	}

	public function create(callable $onSuccess) {
		$form = $this->formFactory->create();

		$form->addText('nazev', 'Název pracoviště');

		$form->addSelect('manazer', 'Manažer', $this->getPracovnik())
			->setAttribute('class', 'chosen');

		$form->addText('pocetProcesu', 'Počet procesů')
			->setDefaultValue(0)
			->setType('number');

		$form->addMultiSelect('pracovniPozicePracoviste', 'Pracovní pozice pracoviště', $this->getPracovniPozicePracoviste())
			->setAttribute('class','chosen');

		$form->addHidden('id');

		$form->addSubmit('send', 'Uložit');

		$form->onSuccess[] = function($form, $values) use($onSuccess) {
			if($values->id){
				$entity = $this->em->getRepository(Pracoviste::class)->find($values->id);
				$entity->clearPracovniPozicePracoviste();
			}else{
				$entity = new Pracoviste();
			}

			$entity->setNazev($values->nazev);
			$manazer = $this->em->getRepository(Pracovnik::class)->find($values->manazer);
			$entity->setManazer($manazer);
			$entity->setPocetProcesu($values->pocetProcesu);

			$repository = $this->em->getRepository(PracovniPozice::class);
			foreach($values->pracovniPozicePracoviste as $pp) {
				$p = $repository->find($pp);
				$entity->addPracovniPozicePracoviste($p);
			}

			$this->em->persist($entity);
			$this->em->flush();

			$onSuccess();
		};

		return $form;
	}

	private function getPracovniPozicePracoviste() {
		$en = $this->em->getRepository(PracovniPozice::class)->findAll();

		$pp = [];
		/** @var PracovniPozice $p */
		foreach($en as $p) {
			$pp[$p->getId()] = $p->getNazevFunkce();
		}

		return $pp;
	}

	private function getPracovnik() {
		$en = $this->em->getRepository(Pracovnik::class)->findAll();

		$p = [];
		/** @var Pracovnik $e */
		foreach($en as $e) {
			$p[$e->getId()] = $e->getPrijmeni()." ".$e->getJmeno();
		}

		return $p;
	}
}