<?php

namespace App\Forms;


use App\Entity\Pracovnik;
use App\Entity\PracovniPozice;
use Doctrine\ORM\EntityManager;
use Nette\Utils\DateTime;

class PracovnikForm
{

	/** @var  FormFactory */
	protected $formFactory;

	/** @var  EntityManager */
	protected $em;

	public function __construct(FormFactory $formFactory, EntityManager $em)
	{
		$this->formFactory = $formFactory;
		$this->em = $em;
	}

	public function create(callable $onSuccess) {
		$form = $this->formFactory->create();

		$form->addText('jmeno', 'Jméno')
			->setRequired();

		$form->addText('prijmeni', 'Příjmení')
			->setRequired();

		$form->addSelect('pracovniPozice', 'Pracovní pozice', $this->getPracovniPozice())
			->setAttribute('class','chosen');

		$form->addText('datumNastupu', 'Datum nástupu');

		$form->addHidden('id');
		$form->addSubmit('send', 'Uložit');

		$form->onSuccess[] = function($form, $values) use($onSuccess) {
			if($values->id) {
				$entity = $this->em->getRepository(Pracovnik::class)->find($values->id);
			}else{
				$entity = new Pracovnik();

			}

			$entity->setJmeno($values->jmeno);
			$entity->setPrijmeni($values->prijmeni);

			$pozice = $this->em->getRepository(PracovniPozice::class)->find($values->pracovniPozice);
			$entity->setPracovniPozice($pozice);
			$entity->setDatumNastupu(new DateTime($values->datumNastupu));

			$this->em->persist($entity);
			$this->em->flush();

			$onSuccess();

		};

		return $form;
	}

	private function getPracovniPozice() {
		$entity = $this->em->getRepository(PracovniPozice::class)->findAll();

		$pp = [];
		/** @var PracovniPozice $p */
		foreach($entity as $p) {
			$pp[$p->getId()] = $p->getNazevFunkce();
		}

		return $pp;
	}
}