<?php

namespace App\Forms;

use Nette;
use Nette\Application\UI\Form;
use App\Model;


class SignUpFormFactory
{
	use Nette\SmartObject;

	const PASSWORD_MIN_LENGTH = 7;

	/** @var FormFactory */
	private $factory;

	/** @var Model\UserManager */
	private $userManager;


	public function __construct(FormFactory $factory, Model\UserManager $userManager)
	{
		$this->factory = $factory;
		$this->userManager = $userManager;
	}


	/**
	 * @return Form
	 */
	public function create(callable $onSuccess)
	{
		$form = $this->factory->create();

		$form->addText('username', 'Už. jméno:')
			->setRequired('Vyplňte už.jméno');

		$form->addText('name', 'Jméno:')
			->setRequired('Vyplňte jméno');

		$form->addEmail('email', 'E-mail:')
			->setRequired('Zadejte email');

		$form->addPassword('password', 'Heslo:')
			->setOption('description', sprintf('nejméně %d znaků', self::PASSWORD_MIN_LENGTH))
			->setRequired('Zadejte heslo.')
			->addRule($form::MIN_LENGTH, NULL, self::PASSWORD_MIN_LENGTH);

		$form->addHidden('id');

		$form->addSubmit('send', 'Uložit');

		$form->onSuccess[] = function (Form $form, $values) use ($onSuccess) {
			try {
				if($values->id) {
					$this->userManager->edit($values->id, $values->name, $values->email, $values->password);
				}else{
					$this->userManager->add($values->username, $values->name, $values->email, $values->password);
				}
			} catch (Model\DuplicateNameException $e) {
				$form['username']->addError('Uživatelské jméno existuje.');
				return;
			}
			$onSuccess();
		};

		return $form;
	}

}
