<?php

namespace App\Presenters;


use App\Entity\Proces;
use App\Forms\ProcesForm;
use App\Grid\ProcesyGrid;
use Doctrine\DBAL\DBALException;

class ProcesyPresenter extends CrudPresenter
{

	/** @var ProcesyGrid @inject */
	public $grid;

	/** @var ProcesForm @inject */
	public $form;


	public function renderAdd() {
		$this->template->title = "Přidat proces";
	}

	public function renderEdit($id) {
		$this->template->title = "Upravit proces";

		/** @var Proces $entity */
		$entity = $this->getEntity($id);

		$pracovnici = [];
		if(count($entity->getPrirazeniPracovnici())) {
			foreach ($entity->getPrirazeniPracovnici() as $prac) {
				$pracovnici[] = $prac->getId();
			}
		}

		$pracoviste = [];
		if(count($entity->getPridelenaPracoviste())) {
			foreach ($entity->getPridelenaPracoviste() as $p) {
				$pracoviste[] = $p->getId();
			}
		}


		$this['editForm']->setDefaults([
			'id' => $entity->getId(),
			'nazev' => $entity->getNazev(),
			'popis' => $entity->getPopis(),
			'dobaTrvaniVMin' => $entity->getDobaTrvaniVMin(),
			'kapacitaPrirazenychPracovniku' => $entity->getKapacitaPrirazenychPracovniku(),
			'cenaProcesu' => $entity->getCenaProcesu()." Kč",
			'prirazeniPracovnici' => $pracovnici,
			'prirazeneProdukty' => $entity->getPrirazeneProdukty() ? $entity->getPrirazeneProdukty()->getId() : NULL,
			'pridelenePracoviste' => $pracoviste
		]);
	}

	private function getEntity($id) {
		return $this->em->getRepository(Proces::class)->find($id);

	}

	public function actionDelete($id) {
		$entity = $this->getEntity($id);
		try {
			$this->em->remove($entity);
			$this->em->flush();
			$this->flashMessage('Objekt byl smazán');
			$this->redirect('default');

		}catch (DBALException $ex) {
			$this->flashMessage('Mazání se nepodařilo');
			$this->redirect('default');
		}
	}

	public function renderDetail($id) {
		$this->template->proces = $this->getEntity($id);
	}
}