<?php

/**
 * This file is part of the Kdyby (http://www.kdyby.org)
 *
 * Copyright (c) 2008 Filip Procházka (filip@prochazka.su)
 *
 * For the full copyright and license information, please view the file license.txt that was distributed with this source code.
 */

namespace Kdyby\Console\DI;

use Kdyby;
use Nette;
use Symfony\Component\Console\Input\ArgvInput;



/**
 * Example app/bootstrap.php file:
 *
 * <code>
 * // Load Nette Framework or autoloader generated by Composer
 * require_once __DIR__ . '/../vendor/autoload.php';
 *
 * // Configure application
 * $configurator = new Nette\Configurator();
 *
 * // Enable Nette Debugger for error visualisation & logging
 * if (Kdyby\Console\DI\BootstrapHelper::setupMode($configurator)) {
 *     // pass
 * } elseif (getenv('NETTE_DEBUG') === '0' || getenv('NETTE_DEBUG') === '1') {
 *     $configurator->setDebugMode((bool) getenv('NETTE_DEBUG'));
 * }
 *
 * $configurator->enableDebugger(__DIR__ . '/../log');
 * </code>
 *
 * @author Filip Procházka <filip@prochazka.su>
 */
class BootstrapHelper extends Nette\Object
{

	/**
	 * @param Nette\Configurator $configurator
	 * @return bool has the debug mode been modified?
	 */
	public static function setupMode(Nette\Configurator $configurator)
	{
		if (PHP_SAPI !== 'cli') {
			return FALSE;
		}

		$input = new ArgvInput();

		if (!$input->hasParameterOption('--debug-mode')) {
			return FALSE;
		}

		if ($input->hasParameterOption(['--debug-mode=no', '--debug-mode=off', '--debug-mode=false', '--debug-mode=0'])) {
			$configurator->setDebugMode(FALSE);
			return TRUE;

		} else {
			$configurator->setDebugMode(TRUE);
			return TRUE;
		}
	}

}
